@@ -20,6 +20,7 @@ from orjson import (
     OPT_PASSTHROUGH_DATACLASS,
     OPT_PASSTHROUGH_DATETIME,
     OPT_SORT_KEYS,
+    JSONDecodeError,
     dumps,
     loads,
 )
@@ -218,9 +219,7 @@ def _pre_process(
         case ZonedDateTime() as date_time:
             return f"[{_Prefixes.zoned_date_time.value}]{date_time}"
         case ZonedDateTimePeriod() as period:
-            return (
-                f"[{_Prefixes.zoned_date_time_period.value}]{period.start},{period.end}"
-            )
+            return f"[{_Prefixes.zoned_date_time_period.value}]{period.start.to_plain()},{period.end}"
         case dt.datetime() as py_datetime:
             match py_datetime.tzinfo:
                 case None:
@@ -373,8 +372,12 @@ def deserialize(
     redirects: Mapping[str, type[Any]] | None = None,
 ) -> Any:
     """Deserialize an object."""
+    try:
+        obj = loads(data)
+    except JSONDecodeError:
+        raise _DeserializeInvalidJSONError(data=data) from None
     return _object_hook(
-        loads(data),
+        obj,
         data=data,
         dataclass_hook=dataclass_hook,
         objects=objects,
@@ -382,6 +385,11 @@ def deserialize(
     )
 
 
+@dataclass(kw_only=True, slots=True)
+class DeerializeError(Exception):
+    obj: Any
+
+
 (
     _DATE_PATTERN,
     _DATE_DELTA_PATTERN,
@@ -512,9 +520,9 @@ def _object_hook(
             if match := _ZONED_DATE_TIME_PATTERN.search(text):
                 return ZonedDateTime.parse_common_iso(match.group(1))
             if match := _ZONED_DATE_TIME_PERIOD_PATTERN.search(text):
-                start, end = map(
-                    ZonedDateTime.parse_common_iso, match.group(1).split(",")
-                )
+                start, end = match.group(1).split(",")
+                end = ZonedDateTime.parse_common_iso(end)
+                start = PlainDateTime.parse_common_iso(start).assume_tz(end.tz)
                 return ZonedDateTimePeriod(start, end)
             if (
                 exc_class := _object_hook_exception_class(
@@ -741,11 +749,19 @@ def _object_hook_get_object(
 @dataclass(kw_only=True, slots=True)
 class DeserializeError(Exception):
     data: bytes
-    qualname: str
+
+
+@dataclass(kw_only=True, slots=True)
+class _DeserializeInvalidJSONError(DeserializeError):
+    @override
+    def __str__(self) -> str:
+        return f"Invalid JSON: {self.data!r}"
 
 
 @dataclass(kw_only=True, slots=True)
 class _DeserializeNoObjectsError(DeserializeError):
+    qualname: str
+
     @override
     def __str__(self) -> str:
         return f"Objects required to deserialize {self.qualname!r} from {self.data!r}"
@@ -753,6 +769,8 @@ class _DeserializeNoObjectsError(DeserializeError):
 
 @dataclass(kw_only=True, slots=True)
 class _DeserializeObjectNotFoundError(DeserializeError):
+    qualname: str
+
     @override
     def __str__(self) -> str:
         return (
