@@ -12,7 +12,7 @@ from typing import TYPE_CHECKING, Literal, assert_never, overload, override
 
 from utilities.contextlib import enhanced_context_manager
 from utilities.errors import ImpossibleCaseError
-from utilities.sentinel import Sentinel, sentinel
+from utilities.sentinel import Sentinel
 
 if TYPE_CHECKING:
     from collections.abc import Iterator, Sequence
@@ -52,33 +52,9 @@ def expand_path(path: PathLike, /) -> Path:
 ##
 
 
-@overload
-def get_path(*, path: MaybeCallablePathLike | None) -> Path: ...
-@overload
-def get_path(*, path: Sentinel) -> Sentinel: ...
-def get_path(
-    *, path: MaybeCallablePathLike | None | Sentinel = sentinel
-) -> Path | None | Sentinel:
-    """Get the path."""
-    match path:
-        case Path() | Sentinel():
-            return path
-        case str():
-            return Path(path)
-        case None:
-            return Path.cwd()
-        case Callable() as func:
-            return get_path(path=func())
-        case _ as never:
-            assert_never(never)
-
-
-##
-
-
-def get_package_root(*, path: MaybeCallablePathLike | None = None) -> Path:
+def get_package_root(path: MaybeCallablePathLike = Path.cwd, /) -> Path:
     """Get the package root."""
-    path = get_path(path=path)
+    path = to_path(path)
     path_dir = path.parent if path.is_file() else path
     all_paths = list(chain([path_dir], path_dir.parents))
     try:
@@ -103,9 +79,9 @@ class GetPackageRootError(Exception):
 ##
 
 
-def get_repo_root(*, path: MaybeCallablePathLike | None = None) -> Path:
+def get_repo_root(path: MaybeCallablePathLike = Path.cwd, /) -> Path:
     """Get the repo root."""
-    path = get_path(path=path)
+    path = to_path(path)
     path_dir = path.parent if path.is_file() else path
     try:
         output = check_output(
@@ -136,15 +112,15 @@ class GetRepoRootError(Exception):
 ##
 
 
-def get_root(*, path: MaybeCallablePathLike | None = None) -> Path:
+def get_root(path: MaybeCallablePathLike = Path.cwd, /) -> Path:
     """Get the root of a path."""
-    path = get_path(path=path)
+    path = to_path(path)
     try:
-        repo = get_repo_root(path=path)
+        repo = get_repo_root(path)
     except GetRepoRootError:
         repo = None
     try:
-        package = get_package_root(path=path)
+        package = get_package_root(path)
     except GetPackageRootError:
         package = None
     match repo, package:
@@ -164,7 +140,7 @@ def get_root(*, path: MaybeCallablePathLike | None = None) -> Path:
             raise ImpossibleCaseError(  # pragma: no cover
                 case=[f"{repo=}", f"{package=}"]
             )
-        case _ as never:
+        case never:
             assert_never(never)
 
 
@@ -213,7 +189,7 @@ def get_tail(
             return _get_tail_core(path, next(iter(matches)))
         case _, "later":
             return _get_tail_core(path, next(iter(reversed(matches))))
-        case _ as never:
+        case never:
             assert_never(never)
 
 
@@ -305,6 +281,30 @@ def temp_cwd(path: PathLike, /) -> Iterator[None]:
         chdir(prev)
 
 
+##
+
+
+@overload
+def to_path(path: Sentinel, /) -> Sentinel: ...
+@overload
+def to_path(path: MaybeCallablePathLike | None = Path.cwd, /) -> Path: ...
+def to_path(
+    path: MaybeCallablePathLike | None | Sentinel = Path.cwd, /
+) -> Path | Sentinel:
+    """Get the path."""
+    match path:
+        case Path() | Sentinel():
+            return path
+        case None:
+            return Path.cwd()
+        case str():
+            return Path(path)
+        case Callable() as func:
+            return to_path(func())
+        case never:
+            assert_never(never)
+
+
 __all__ = [
     "PWD",
     "GetPackageRootError",
@@ -313,11 +313,11 @@ __all__ = [
     "ensure_suffix",
     "expand_path",
     "get_package_root",
-    "get_path",
     "get_repo_root",
     "get_tail",
     "is_sub_path",
     "list_dir",
     "module_path",
     "temp_cwd",
+    "to_path",
 ]
