@@ -53,11 +53,11 @@ from polars.schema import Schema
 from polars.testing import assert_frame_equal, assert_series_equal
 from whenever import DateDelta, DateTimeDelta, PlainDateTime, TimeDelta, ZonedDateTime
 
+import utilities.math
 from utilities.dataclasses import yield_fields
 from utilities.errors import ImpossibleCaseError
 from utilities.functions import (
-    EnsureIntError,
-    ensure_int,
+    get_class_name,
     is_dataclass_class,
     is_dataclass_instance,
     make_isinstance,
@@ -80,12 +80,12 @@ from utilities.iterables import (
 )
 from utilities.json import write_formatted_json
 from utilities.math import (
+    MAX_DECIMALS,
     CheckIntegerError,
     check_integer,
     ewm_parameters,
     is_less_than,
     is_non_negative,
-    number_of_decimals,
 )
 from utilities.reprlib import get_repr
 from utilities.types import MaybeStr, Number, PathLike, WeekDay
@@ -104,7 +104,7 @@ from utilities.whenever import (
     ZonedDateTimePeriod,
     to_py_time_delta,
 )
-from utilities.zoneinfo import UTC, ensure_time_zone, get_time_zone_name
+from utilities.zoneinfo import UTC, to_time_zone_name
 
 if TYPE_CHECKING:
     from collections.abc import Callable, Iterable, Iterator, Mapping, Sequence
@@ -834,7 +834,7 @@ def convert_time_zone(
 
 def _convert_time_zone_one(sr: Series, /, *, time_zone: TimeZoneLike = UTC) -> Series:
     if isinstance(sr.dtype, Datetime):
-        return sr.dt.convert_time_zone(get_time_zone_name(time_zone))
+        return sr.dt.convert_time_zone(to_time_zone_name(time_zone))
     return sr
 
 
@@ -1325,10 +1325,15 @@ class _FiniteEWMWeightsError(Exception):
 ##
 
 
-def first_true_horizontal(df: DataFrame, /) -> Series:
+@overload
+def first_true_horizontal(*columns: Series) -> Series: ...
+@overload
+def first_true_horizontal(*columns: IntoExprColumn) -> ExprOrSeries: ...
+def first_true_horizontal(*columns: IntoExprColumn) -> ExprOrSeries:
     """Get the index of the first true in each row."""
-    expr = when(any_horizontal(pl.all())).then(concat_list(pl.all()).list.arg_max())
-    return one_column(df.select(expr))
+    columns2 = ensure_expr_or_series_many(*columns)
+    expr = when(any_horizontal(*columns2)).then(concat_list(*columns2).list.arg_max())
+    return try_reify_expr(expr, *columns2)
 
 
 ##
@@ -1427,56 +1432,6 @@ def get_frequency_spectrum(series: Series, /, *, d: int = 1) -> DataFrame:
 ##
 
 
-@overload
-def get_series_number_of_decimals(
-    series: Series, /, *, nullable: Literal[True]
-) -> int | None: ...
-@overload
-def get_series_number_of_decimals(
-    series: Series, /, *, nullable: Literal[False] = False
-) -> int: ...
-@overload
-def get_series_number_of_decimals(
-    series: Series, /, *, nullable: bool = False
-) -> int | None: ...
-def get_series_number_of_decimals(
-    series: Series, /, *, nullable: bool = False
-) -> int | None:
-    """Get the number of decimals of a series."""
-    if not isinstance(dtype := series.dtype, Float64):
-        raise _GetSeriesNumberOfDecimalsNotFloatError(dtype=dtype)
-    decimals = series.map_elements(number_of_decimals, return_dtype=Int64).max()
-    try:
-        return ensure_int(decimals, nullable=nullable)
-    except EnsureIntError:
-        raise _GetSeriesNumberOfDecimalsAllNullError(series=series) from None
-
-
-@dataclass(kw_only=True, slots=True)
-class GetSeriesNumberOfDecimalsError(Exception): ...
-
-
-@dataclass(kw_only=True, slots=True)
-class _GetSeriesNumberOfDecimalsNotFloatError(GetSeriesNumberOfDecimalsError):
-    dtype: DataType
-
-    @override
-    def __str__(self) -> str:
-        return f"Data type must be Float64; got {self.dtype}"
-
-
-@dataclass(kw_only=True, slots=True)
-class _GetSeriesNumberOfDecimalsAllNullError(GetSeriesNumberOfDecimalsError):
-    series: Series
-
-    @override
-    def __str__(self) -> str:
-        return f"Series must not be all-null; got {self.series}"
-
-
-##
-
-
 @overload
 def increasing_horizontal(*columns: ExprLike) -> Expr: ...
 @overload
@@ -1951,40 +1906,26 @@ def _map_over_series_one(func: Callable[[Series], Series], series: Series, /) ->
 ##
 
 
-def nan_sum_agg(column: str | Expr, /, *, dtype: PolarsDataType | None = None) -> Expr:
+def nan_sum_agg(column: str | Expr, /) -> Expr:
     """Nan sum aggregation."""
     col_use = col(column) if isinstance(column, str) else column
-    return (
-        when(col_use.is_not_null().any())
-        .then(col_use.sum())
-        .otherwise(lit(None, dtype=dtype))
-    )
+    return when(col_use.is_not_null().any()).then(col_use.sum())
 
 
 ##
 
 
-def nan_sum_cols(
-    column: str | Expr, *columns: str | Expr, dtype: PolarsDataType | None = None
-) -> Expr:
+@overload
+def nan_sum_horizontal(*columns: Series) -> Series: ...
+@overload
+def nan_sum_horizontal(*columns: IntoExprColumn) -> ExprOrSeries: ...
+def nan_sum_horizontal(*columns: IntoExprColumn) -> ExprOrSeries:
     """Nan sum across columns."""
-    all_columns = chain([column], columns)
-    all_exprs = (
-        col(column) if isinstance(column, str) else column for column in all_columns
+    columns2 = ensure_expr_or_series_many(*columns)
+    expr = when(any_horizontal(*(c.is_not_null() for c in columns2))).then(
+        sum_horizontal(*columns2)
     )
-
-    def func(x: Expr, y: Expr, /) -> Expr:
-        return (
-            when(x.is_not_null() & y.is_not_null())
-            .then(x + y)
-            .when(x.is_not_null() & y.is_null())
-            .then(x)
-            .when(x.is_null() & y.is_not_null())
-            .then(y)
-            .otherwise(lit(None, dtype=dtype))
-        )
-
-    return reduce(func, all_exprs)
+    return try_reify_expr(expr, *columns2)
 
 
 ##
@@ -2023,6 +1964,38 @@ def normal(
 ##
 
 
+@overload
+def number_of_decimals(
+    series: ExprLike, /, *, max_decimals: int = MAX_DECIMALS
+) -> Expr: ...
+@overload
+def number_of_decimals(
+    series: Series, /, *, max_decimals: int = MAX_DECIMALS
+) -> Series: ...
+@overload
+def number_of_decimals(
+    series: IntoExprColumn, /, *, max_decimals: int = MAX_DECIMALS
+) -> ExprOrSeries: ...
+def number_of_decimals(
+    series: IntoExprColumn, /, *, max_decimals: int = MAX_DECIMALS
+) -> ExprOrSeries:
+    """Get the number of decimals."""
+    series = ensure_expr_or_series(series)
+    frac = series - series.floor()
+    results = (
+        _number_of_decimals_check_scale(frac, s) for s in range(max_decimals + 1)
+    )
+    return first_true_horizontal(*results)
+
+
+def _number_of_decimals_check_scale(frac: ExprOrSeries, scale: int, /) -> ExprOrSeries:
+    scaled = 10**scale * frac
+    return is_close(scaled, scaled.round()).alias(str(scale))
+
+
+##
+
+
 def offset_datetime(
     datetime: ZonedDateTime, offset: str, /, *, n: int = 1
 ) -> ZonedDateTime:
@@ -2137,7 +2110,7 @@ def period_range(
     eager: bool = False,
 ) -> Series | Expr:
     """Construct a period range."""
-    time_zone_use = None if time_zone is None else ensure_time_zone(time_zone).key
+    time_zone_use = None if time_zone is None else to_time_zone_name(time_zone)
     match end_or_length:
         case ZonedDateTime() as end:
             ...
@@ -2154,7 +2127,7 @@ def period_range(
         time_zone=time_zone_use,
         eager=eager,
     ).alias("start")
-    ends = (starts.dt.offset_by(interval)).alias("end")
+    ends = starts.dt.offset_by(interval).alias("end")
     period = struct(starts, ends)
     return try_reify_expr(period, starts, ends)
 
@@ -2247,7 +2220,7 @@ def _replace_time_zone_one(
     sr: Series, /, *, time_zone: TimeZoneLike | None = UTC
 ) -> Series:
     if isinstance(sr.dtype, Datetime):
-        time_zone_use = None if time_zone is None else get_time_zone_name(time_zone)
+        time_zone_use = None if time_zone is None else to_time_zone_name(time_zone)
         return sr.dt.replace_time_zone(time_zone_use)
     return sr
 
@@ -2377,19 +2350,96 @@ def round_to_float(
 ) -> Expr: ...
 @overload
 def round_to_float(
-    x: Series, y: float, /, *, mode: RoundMode = "half_to_even"
+    x: Series, y: float | ExprOrSeries, /, *, mode: RoundMode = "half_to_even"
 ) -> Series: ...
 @overload
 def round_to_float(
-    x: IntoExprColumn, y: float, /, *, mode: RoundMode = "half_to_even"
+    x: ExprLike, y: Series, /, *, mode: RoundMode = "half_to_even"
+) -> Series: ...
+@overload
+def round_to_float(
+    x: ExprLike, y: Expr, /, *, mode: RoundMode = "half_to_even"
+) -> Expr: ...
+@overload
+def round_to_float(
+    x: IntoExprColumn, y: float | Series, /, *, mode: RoundMode = "half_to_even"
 ) -> ExprOrSeries: ...
 def round_to_float(
-    x: IntoExprColumn, y: float, /, *, mode: RoundMode = "half_to_even"
+    x: IntoExprColumn, y: float | IntoExprColumn, /, *, mode: RoundMode = "half_to_even"
 ) -> ExprOrSeries:
     """Round a column to the nearest multiple of another float."""
     x = ensure_expr_or_series(x)
-    z = (x / y).round(mode=mode) * y
-    return z.round(decimals=number_of_decimals(y) + 1)
+    y = y if isinstance(y, int | float) else ensure_expr_or_series(y)
+    match x, y:
+        case Expr() | Series(), int() | float():
+            z = (x / y).round(mode=mode) * y
+            return z.round(decimals=utilities.math.number_of_decimals(y) + 1)
+        case Series(), Expr() | Series():
+            df = (
+                x.to_frame()
+                .with_columns(y)
+                .with_columns(number_of_decimals(y).alias("_decimals"))
+                .with_row_index(name="_index")
+                .group_by("_decimals")
+                .map_groups(_round_to_float_one)
+                .sort("_index")
+            )
+            return df[df.columns[1]]
+        case Expr(), Series():
+            df = y.to_frame().with_columns(x)
+            return round_to_float(df[df.columns[1]], df[df.columns[0]], mode=mode)
+        case Expr(), Expr() | str():
+            raise RoundToFloatError(x=x, y=y)
+        case never:
+            assert_never(never)
+
+
+def _round_to_float_one(df: DataFrame, /) -> DataFrame:
+    decimals: int | None = df["_decimals"].unique().item()
+    name = df.columns[1]
+    match decimals:
+        case int():
+            expr = col(name).round(decimals=decimals)
+        case None:
+            expr = lit(None, dtype=Float64).alias(name)
+        case never:
+            assert_never(never)
+    return df.with_columns(expr)
+
+
+@dataclass(kw_only=True, slots=True)
+class RoundToFloatError(Exception):
+    x: IntoExprColumn
+    y: IntoExprColumn
+
+    @override
+    def __str__(self) -> str:
+        return f"At least 1 of the dividend and/or divisor must be a Series; got {get_class_name(self.x)!r} and {get_class_name(self.y)!r}"
+
+
+##
+
+
+def select_exact(
+    df: DataFrame, /, *columns: IntoExprColumn, drop: MaybeIterable[str] | None = None
+) -> DataFrame:
+    """Select an exact set of columns from a DataFrame."""
+    names = [get_expr_name(df, c) for c in columns]
+    drop = set() if drop is None else set(always_iterable(drop))
+    union = set(names) | drop
+    extra = [c for c in df.columns if c not in union]
+    if len(extra) >= 1:
+        raise SelectExactError(columns=extra)
+    return df.select(*columns)
+
+
+@dataclass(kw_only=True, slots=True)
+class SelectExactError(Exception):
+    columns: list[str]
+
+    @override
+    def __str__(self) -> str:
+        return f"All columns must be selected; got {get_repr(self.columns)} remaining"
 
 
 ##
@@ -2561,7 +2611,7 @@ def zoned_date_time_dtype(
     *, time_unit: TimeUnit = "us", time_zone: TimeZoneLike = UTC
 ) -> Datetime:
     """Create a zoned date-time data type."""
-    return Datetime(time_unit=time_unit, time_zone=get_time_zone_name(time_zone))
+    return Datetime(time_unit=time_unit, time_zone=to_time_zone_name(time_zone))
 
 
 def zoned_date_time_period_dtype(
@@ -2595,7 +2645,6 @@ __all__ = [
     "ExprOrSeries",
     "FiniteEWMMeanError",
     "GetDataTypeOrSeriesTimeZoneError",
-    "GetSeriesNumberOfDecimalsError",
     "InsertAfterError",
     "InsertBeforeError",
     "InsertBetweenError",
@@ -2603,6 +2652,8 @@ __all__ = [
     "OneColumnEmptyError",
     "OneColumnError",
     "OneColumnNonUniqueError",
+    "RoundToFloatError",
+    "SelectExactError",
     "SetFirstRowAsColumnsError",
     "TimePeriodDType",
     "acf",
@@ -2634,7 +2685,6 @@ __all__ = [
     "get_data_type_or_series_time_zone",
     "get_expr_name",
     "get_frequency_spectrum",
-    "get_series_number_of_decimals",
     "increasing_horizontal",
     "insert_after",
     "insert_before",
@@ -2648,8 +2698,9 @@ __all__ = [
     "join_into_periods",
     "map_over_columns",
     "nan_sum_agg",
-    "nan_sum_cols",
+    "nan_sum_horizontal",
     "normal",
+    "number_of_decimals",
     "offset_datetime",
     "one_column",
     "order_of_magnitude",
@@ -2658,6 +2709,7 @@ __all__ = [
     "read_series",
     "replace_time_zone",
     "round_to_float",
+    "select_exact",
     "serialize_dataframe",
     "set_first_row_as_columns",
     "struct_dtype",
